netapp_ontap.models.gcp_kms_key API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.gcp_kms_key`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class GcpKmsKeySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the GcpKmsKey object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `key_name: str GET POST`

    Google Cloud KMS key name.

    Example: cryptokey1

  `key_ring_location: str GET POST`

    Google Cloud KMS key ring location.

    Example: location1

  `key_ring_name: str GET POST`

    Google Cloud KMS key ring name.

    Example: keyring1

  `project_id: str GET POST`

    Google Cloud KMS project ID.

    Example: project1